@@ -286,9 +286,9 @@ abc.internal <- function (object,
   if (is.null(probes))
     pStop_(sQuote("probes")," must be specified.")
   if (!is.list(probes)) probes <- list(probes)
-  if (!all(sapply(probes,is.function)))
+  if (!all(vapply(probes,is.function,logical(1L))))
     pStop_(sQuote("probes")," must be a function or a list of functions.")
-  if (!all(sapply(probes,function(f)length(formals(f))==1)))
+  if (!all(vapply(probes,\(f)length(formals(f))==1L,logical(1L))))
     pStop_("each probe must be a function of a single argument.")
 
   if (length(scale)==0)
@@ -385,7 +385,7 @@ abc.internal <- function (object,
 
   }
 
-  pars <- apply(traces,2,function(x)diff(range(x))>0)
+  pars <- apply(traces,2L,\(x)diff(range(x))>0)
   pars <- names(pars[pars])
 
   new(
