@@ -485,63 +485,4 @@ eakf.internal <- function (object, Np, ..., verbose) {
     cond.logLik=condlogLik,
     loglik=sum(condlogLik)
   )
-
-}
-
-## Basic Kalman filter. Currently for internal consumption only.
-## X(t) ~ MVN(A*X(t-1),Q)
-## Y(t) ~ MVN(C*X(t),R)
-
-kalmanFilter <- function (t, y, X0, A, Q, C, R) {
-
-  N <- ncol(y)
-  nvar <- length(X0)
-  nobs <- nrow(y)
-
-  filterMeans <- array(dim=c(nvar,N),
-    dimnames=list(variable=names(X0),time=NULL))
-  predMeans <- filterMeans
-  forecast <- array(dim=c(nobs,N),dimnames=dimnames(y))
-  condlogLik <- numeric(N)
-
-  ri <- solve(R)
-  cric <- crossprod(C,ri)%*%C
-  fm <- X0
-  fv <- matrix(0,nvar,nvar)
-
-  for (k in seq_along(t)) {
-
-    predMeans[,k] <- pm <- A%*%fm      # prediction mean
-    pv <- A%*%tcrossprod(fv,A)+Q       # prediction variance
-
-    svdV <- svd(pv,nv=0)
-
-    resid <- y[,k]-C%*%pm              # forecast error
-    w <- tcrossprod(C%*%pv,C)+R        # forecast variance
-
-    svdW <- svd(w,nv=0)
-
-    condlogLik[k] <- sum(dnorm(x=crossprod(svdW$u,resid),mean=0,
-      sd=sqrt(svdW$d),log=TRUE))
-
-    pvi <- svdV$u%*%(t(svdV$u)/svdV$d) # prediction precision
-    fvi <- pvi+cric                    # filter precision
-
-    svdv <- svd(fvi,nv=0)
-
-    fv <- svdv$u%*%(t(svdv$u)/svdv$d)  # filter variance
-    K <- fv%*%crossprod(C,ri)          # Kalman gain
-
-    filterMeans[,k] <- fm <- pm+K%*%resid  # filter mean
-    forecast[,k] <- C %*% pm
-  }
-
-  list(
-    filterMeans=filterMeans,
-    predMeans=predMeans,
-    forecast=forecast,
-    cond.logLik=condlogLik,
-    loglik=sum(condlogLik)
-  )
-
 }
