@@ -3,6 +3,7 @@
 ##' Extract the data array from a \sQuote{pomp} object.
 ##'
 ##' @name obs
+##' @aliases obs,ANY-method obs,missing-method
 ##' @docType methods
 ##' @rdname obs
 ##' @include pomp_class.R
@@ -17,6 +18,22 @@ setGeneric(
         standardGeneric("obs")
 )
 
+setMethod(
+  "obs",
+  signature=signature(object="missing"),
+  definition=function (object, ...) {
+    reqd_arg("obs","object")
+  }
+)
+
+setMethod(
+  "obs",
+  signature=signature(object="ANY"),
+  definition=function (object, ...) {
+    undef_method("obs","object")
+  }
+)
+
 ##' @rdname obs
 ##' @param object an object of class \sQuote{pomp}, or of a class extending \sQuote{pomp}
 ##' @param vars names of variables to retrieve
