@@ -406,7 +406,7 @@ setMethod(
     if (missing(cfile)) cfile <- NULL
     if (!is.null(cfile)) {
       cfile <- as.character(cfile)
-      fnames <- unlist(sapply(data@solibs,getElement,"name"))
+      fnames <- unlist(lapply(data@solibs,getElement,"name"))
       if (any(cfile==fnames)) {
         pStop_("C file name ",dQuote(cfile)," cannot be re-used.")
       }
@@ -506,7 +506,7 @@ pomp.internal <- function (data, times, t0, timename, ...,
 
   ## store the data as double-precision matrix
   storage.mode(data) <- "double"
-  if (is.null(obsnames)) obsnames <- rownames(data)
+  if (is.null(obsnames)) obsnames <- row.names(data)
 
   ## check the parameters and force them to be double-precision
   params <- tryCatch(
