@@ -3,6 +3,7 @@
 ##' Extract the latent states from a \sQuote{pomp} object.
 ##'
 ##' @name states
+##' @aliases states,ANY-method states,missing-method
 ##' @rdname states
 ##' @docType methods
 ##' @include pomp_class.R
@@ -17,6 +18,22 @@ setGeneric(
     standardGeneric("states")
 )
 
+setMethod(
+  "states",
+  signature=signature(object="missing"),
+  definition=function (object, ...) {
+    reqd_arg("states","object")
+  }
+)
+
+setMethod(
+  "states",
+  signature=signature(object="ANY"),
+  definition=function (object, ...) {
+    undef_method("states","object")
+  }
+)
+
 ##' @rdname states
 ##' @inheritParams obs
 ##' @export
