@@ -2,6 +2,7 @@
 #include <R_ext/Rdynload.h>
 
 static const R_CallMethodDef callMethods[] = {
+  {"logmeanexp", (DL_FUNC) &logmeanexp, 2},
   {"bspline_basis", (DL_FUNC) &bspline_basis, 5},
   {"periodic_bspline_basis", (DL_FUNC) &periodic_bspline_basis, 5},
   {"systematic_resampling", (DL_FUNC) &systematic_resampling, 2},
@@ -51,6 +52,7 @@ static const R_CallMethodDef callMethods[] = {
 
 void R_init_pomp (DllInfo *info) {
   // C functions provided for users
+  R_RegisterCCallable("pomp","bspline_eval",(DL_FUNC) &bspline_eval);
   R_RegisterCCallable("pomp","periodic_bspline_basis_eval",(DL_FUNC) &periodic_bspline_basis_eval);
   R_RegisterCCallable("pomp","get_userdata",(DL_FUNC) &get_userdata);
   R_RegisterCCallable("pomp","get_userdata_int",(DL_FUNC) &get_userdata_int);
